@@ -1,6 +1,6 @@
 package Dancer2::Plugin::Auth::Extensible;
 
-our $VERSION = '0.612';
+our $VERSION = '0.613';
 
 use strict;
 use warnings;
@@ -1141,10 +1141,6 @@ This framework supplies the following providers out-of-the-box:
 
 Authenticates users using system accounts on Linux/Unix type boxes
 
-=item L<Dancer2::Plugin::Auth::Extensible::Provider::Database>
-
-Authenticates users stored in a database table
-
 =item L<Dancer2::Plugin::Auth::Extensible::Provider::Config>
 
 Authenticates users stored in the app's config
@@ -1159,6 +1155,10 @@ The following external providers are also available on the CPAN:
 
 Authenticates users stored in a database table using L<Dancer2::Plugin::DBIC>
 
+=item L<Dancer2::Plugin::Auth::Extensible::Provider::Database>
+
+Authenticates users stored in a database table
+
 =back
 
 Need to write your own?  Just create a new provider class which consumes
@@ -1793,7 +1793,7 @@ LDAP provider added by Mark Meyer (ofosos)
 
 Documentation fix by Vince Willems.
 
-Henk van Oers (GH #8, #13).
+Henk van Oers (GH #8, #13, #55).
 
 Andrew Beverly (GH #6, #7, #10, #17, #22, #24, #25, #26, #54).
 This includes support for creating and editing users and manage user passwords.
